@@ -36,7 +36,7 @@ def buildAdvancedPriceFeatures(quotes_df=None, lookback_window=20, rolling_direc
 
 
 class AbstractAssembler(ABC):
-    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
+    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
         super().__init__()
         self.local_root_directory = local_root_directory
         self.user = user
@@ -45,6 +45,7 @@ class AbstractAssembler(ABC):
         self.features_names_saving_suffix = features_names_saving_suffix
         self.returns_pkl_file_name = returns_pkl_file_name
         self.macro_features_directory = macro_features_directory
+        self.shortcut_features_pkl_file_name = shortcut_features_pkl_file_name
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
         self.running_date=running_date
         self.starting_date=starting_date
@@ -71,6 +72,7 @@ class FeaturesAssembler(AbstractAssembler):
 
         advanced_features, advanced_features_names = self.preprocessFeatures()
         df, strats, strat_features_names = self.preprocessReturns(tsfresh_lookback_window)
+        shortcut_df = self.preprocessShortcutFeatures()
 
 
         features_names = [col for col in list(advanced_features.columns) if col != 'Date']
@@ -189,6 +191,9 @@ class FeaturesAssembler(AbstractAssembler):
         return all_merged_df, macro_features
 
 
+
+
+
     def preprocessFeatures(self):
 
         features = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder=self.macro_features_directory, returns_pkl_file_name=self.features_pkl_file_name, local_root_directory = Path(self.local_root_directory))
@@ -263,6 +268,14 @@ class FeaturesAssembler(AbstractAssembler):
 
         return features , features_names
 
+    def preprocessShortcutFeatures(self):
+        shortcut_df = self.dbx.local_overwrite_and_load_pickle(folder='', subfolder='',
+                                                      returns_pkl_file_name=self.shortcut_features_pkl_file_name,
+                                                      local_root_directory=self.local_root_directory)
+        shortcut_df = shortcut_df[shortcut_df.index >= self.starting_date]
+        shortcut_df = shortcut_df[shortcut_df.index <= self.ending_date]
+        return shortcut_df
+
     def preprocessReturns(self, lookback_window, ts_fresh_indices = ['SPXT'], add_signal_predictor = False):
 
         df = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder='', returns_pkl_file_name=self.returns_pkl_file_name, local_root_directory = self.local_root_directory)
